//alert('here');
dojo.require("dojo.parser");
dojo.require("dojox.data.QueryReadStore");
dojo.require("dojox.grid.DataGrid");
dojo.require("dojo._base.xhr");
dojo.__XhrArgs = {preventCache:true}
//dojo.addOnLoad(
//    function(){
//        dojo.parser.parse();
//    });

